diff --git a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryMakeMKGeneration.java b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryMakeMKGeneration.java
index 79495e9cf63f584187c0e0cc16f6ed2bd7eac112..0c8b68c4adc341b02eaa13b484fd585436fcd11d 100644
--- a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryMakeMKGeneration.java
+++ b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryMakeMKGeneration.java
@@ -17,6 +17,9 @@ $Id$
 +--------------------------------------------------------------------------*/
 package org.fortiss.af3.platform.raspberry.generated.files;
 
+import java.io.FileNotFoundException;
+import java.io.UnsupportedEncodingException;
+
 /**
  * 
  * @author zverlov
@@ -34,7 +37,29 @@ public class RaspberryMakeMKGeneration {
 	}
 
 	/** Main methods for creation of make.mk. */
+	/**
+	 * public void createMakeMK(){
+	 * 
+	 * }
+	 */
+
+	/**
+	 * @throws FileNotFoundException
+	 * @throws UnsupportedEncodingException
+	 */
 	public void createMakeMK() {
+
+		/*
+		 * FileInputStream fis = new FileInputStream("C:\\Users\\Khan\\Desktop\\make.txt");
+		 * InputStreamReader in = new InputStreamReader(fis, "US-ASCII");// UTF-8
+		 * 
+		 * content += in;
+		 */
+		content +=
+				"test:\n	@echo  $(@D)\n	@echo  $(DEPS)\n	@echo  $(OBJECTS2)\n	@echo Test\n	@echo $(C_SRC)\n	@echo Test\n	@echo $(H_SRC)\n	@echo Test\n	@echo $(LIBRARY)\n";
+		content +=
+				"run: all\n	@./$(TARGET)\n\nramdisk:\n	sudo mkdir $(RAMDISK_DIR)\n	sudo mount -t tmpfs -o size=512m tmpfs $(RAMDISK_DIR)\n\n\n.PHONY: test deploy all ramdisk ";
+		// FileOutputStream fos = new FileOutputStream("test.txt");
 		// TODO: needs to be implemented
 	}
 
diff --git a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryMakefileGeneration.java b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryMakefileGeneration.java
index af5c55bd6a91280c4989f680071c4b040baf2bfc..c3e811d3752c2fdcd12a8393ba691f75cf3aaa9c 100644
--- a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryMakefileGeneration.java
+++ b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryMakefileGeneration.java
@@ -48,7 +48,11 @@ public class RaspberryMakefileGeneration {
 	/** This methods is only an example. */
 	private void printFirstTwoLines() {
 		content += "SHELL := /bin/bash" + "\n\n";
-		content += "TARGET = " + binaryTargetName + "\n";
+		content += "TARGET = " + binaryTargetName + "\n\n";
+		content += "C_SRC   :=  $(wildcard *.c)\n";
+		content += "CPP_SRC :=  $(wildcard *.cpp)\n";
+		content += "H_SRC   :=  $(wildcard *.h)\n";
+		content += "H_SRC   :=  $(wildcard *.h)\n";
 
 	}
 
diff --git a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generator/executable/BusExecutable.java b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generator/executable/BusExecutable.java
index 6119881dc8ec4b802e20e0864960971598c273f3..50c5d313e45af9b6ba807e9f9e7e4b27de09099e 100644
--- a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generator/executable/BusExecutable.java
+++ b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generator/executable/BusExecutable.java
@@ -17,15 +17,21 @@ $Id$
 +--------------------------------------------------------------------------*/
 package org.fortiss.af3.platform.raspberry.generator.executable;
 
+import static org.fortiss.af3.generator.common.utils.SourceModelElementFactory.createStaticContentSourceUnit;
+
 import java.util.List;
 import java.util.Map;
 
 import org.fortiss.af3.component.model.Component;
+import org.fortiss.af3.component.model.InputPort;
+import org.fortiss.af3.component.model.OutputPort;
 import org.fortiss.af3.component.model.Port;
+import org.fortiss.af3.component.model.PortSpecification;
 import org.fortiss.af3.generator.common.model.source.SourcePackage;
 import org.fortiss.af3.platform.language.executable.TransmissionUnitExecutableBase;
 import org.fortiss.af3.platform.model.ExecutionUnit;
 import org.fortiss.af3.platform.model.TransmissionUnit;
+import org.fortiss.af3.platform.raspberry.generated.files.RaspberryPortTypeGeneration;
 
 /**
  * 
@@ -49,16 +55,52 @@ public class BusExecutable extends TransmissionUnitExecutableBase<TransmissionUn
 	public void createAllFiles(SourcePackage pack, Map<ExecutionUnit, List<Port>> euPortsPair,
 			Map<ExecutionUnit, List<Component>> euComponentList, Component topComponent,
 			int deploymentID) {
-		checkTypesOfOutputPorts(euPortsPair);
-
+		checkTypesOfOutputPorts(pack, euPortsPair);
 	}
 
 	/** Collects the information about type and bounds of all OutputPorts. */
-	public void checkTypesOfOutputPorts(Map<ExecutionUnit, List<Port>> portsToCheck) {
+	public void checkTypesOfOutputPorts(SourcePackage pack,
+			Map<ExecutionUnit, List<Port>> portsToCheck) {
 
 		// TODO: Look at all ports, which are OutputPorts (instanceof OutputPort)
 		// save for each port the type (i.e.: int) and the upper+lower bounds
 		// create a simple string template for the output
+		// String Keys;
+		String logPortSpecs = new String();
+		String portName = new String();
+		String portType = new String();
+
+		Object[] ecus = portsToCheck.keySet().toArray();
+		for(Object ecu : ecus) { // Iterate over number of Cores
+			for(Object port : portsToCheck.get(ecu)) { // Iterate over Number of Ports.
+				if(port instanceof InputPort) {
+					portName = ((InputPort)port).getName();
+					PortSpecification portSpecIn =
+							(PortSpecification)((InputPort)port).getSpecifications().get(0);
+					portType = portSpecIn.getType().toString();
+					// logPortSpecification(portName, portSpecIn, "Input");
+					logPortSpecs +=
+							"Input PortName:  " + portName + "\nType:      " + portType + "\n\n";
+
+				} else if(port instanceof OutputPort) {
+					portName = ((OutputPort)port).getName();
+					PortSpecification portSpecOut =
+							(PortSpecification)((OutputPort)port).getSpecifications().get(0);
+					portType = portSpecOut.getType().toString();
+					// logPortSpecification(portName, portSpecOut, "Output");
+					logPortSpecs +=
+							"Output PortName:  " + portName + "\nType:      " + portType + "\n\n";
+
+				} else {
+					System.out.println("Not a port!");
+				}
+			}
+		}
+		RaspberryPortTypeGeneration rspPortInfoGen = new RaspberryPortTypeGeneration(logPortSpecs);
+		rspPortInfoGen.createInfofile();
+		pack.addUnit(createStaticContentSourceUnit("PortSpecifications",
+				rspPortInfoGen.getContent(), false));
+
 	}
 
 }
diff --git a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generator/executable/CANBusExecutable.java b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generator/executable/CANBusExecutable.java
index a5faebdc135a9950dfe7893ea59ce6767bc9e799..0ebda1f1048f2b62c08ef0dbde0340c053750279 100644
--- a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generator/executable/CANBusExecutable.java
+++ b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generator/executable/CANBusExecutable.java
@@ -17,6 +17,8 @@ $Id$
 +--------------------------------------------------------------------------*/
 package org.fortiss.af3.platform.raspberry.generator.executable;
 
+import static org.fortiss.af3.generator.common.utils.SourceModelElementFactory.createStaticContentSourceUnit;
+
 import java.util.List;
 import java.util.Map;
 
@@ -26,6 +28,7 @@ import org.fortiss.af3.generator.common.model.source.SourcePackage;
 import org.fortiss.af3.platform.language.executable.TransmissionUnitExecutableBase;
 import org.fortiss.af3.platform.model.ExecutionUnit;
 import org.fortiss.af3.platform.model.TransmissionUnit;
+import org.fortiss.af3.platform.raspberry.templates.RaspberryTemplateLoader;
 
 /**
  * 
@@ -49,7 +52,19 @@ public class CANBusExecutable extends TransmissionUnitExecutableBase<Transmissio
 	public void createAllFiles(SourcePackage pack, Map<ExecutionUnit, List<Port>> euPortsPair,
 			Map<ExecutionUnit, List<Component>> euComponentList, Component topComponent,
 			int deploymentID) {
-		System.out.println("hello");
+		createMakeFileUsingTemplate(pack, "test_targetName");
+		createMakeMKUsingTemplate(pack);
+	}
+
+	/** Creates a Makefile for an executable with a certain target name. */
+	private void createMakeFileUsingTemplate(SourcePackage pack, String targetName) {
+		String content = RaspberryTemplateLoader.getMakeFileTemplate(targetName).toString();
+		pack.addUnit(createStaticContentSourceUnit("Makefile", content, false));
 	}
 
+	/** Creates the make.mk file. */
+	private void createMakeMKUsingTemplate(SourcePackage pack) {
+		String content = RaspberryTemplateLoader.getMakeMkTemplate().toString();
+		pack.addUnit(createStaticContentSourceUnit("make.mk", content, false));
+	}
 }
diff --git a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/templates/RaspberryTemplateLoader.java b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/templates/RaspberryTemplateLoader.java
index 6b83a00441c6338df9326c7a9dbde77c7c89a97a..aa0994f8f66da09acb861083a6a0aeffb4254500 100644
--- a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/templates/RaspberryTemplateLoader.java
+++ b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/templates/RaspberryTemplateLoader.java
@@ -55,11 +55,17 @@ public class RaspberryTemplateLoader {
 
 	/** Returns the Template of a Makefile for the Raspberry Platform. */
 	public static StringTemplate getMakeFileTemplate(String binaryName) {
+		/*
+		 * return loadResourceSTG(RaspberryTemplateLoader.class, "MakeFileTemplate").getInstanceOf(
+		 * "MakeFileTemplate");
+		 */
+
 		StringTemplate template =
 				loadResourceSTG(RaspberryTemplateLoader.class, "MakeFileTemplate").getInstanceOf(
 						"MakeFileTemplate");
 		template.setAttribute("binaryName", binaryName);
 		return template;
+
 	}
 
 	/** Returns the Template of make.mk file for the Raspberry Platform. */
@@ -81,4 +87,13 @@ public class RaspberryTemplateLoader {
 		template.setAttribute("headerFile", headerFile);
 		return template;
 	}
+
+	public static StringTemplate getMakeMkTemplate() {
+		StringTemplate template =
+				loadResourceSTG(RaspberryTemplateLoader.class, "MakeMkTemplate").getInstanceOf(
+						"MakeMkTemplate");
+		// template.setAttribute("binaryName", binaryName);
+		return template;
+
+	}
 }
diff --git a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryPortTypeGeneration.java b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryPortTypeGeneration.java
index a729a7c10301623ddb7a9d376ef76838e8cb61a9..b5798a0b02919a0361d951602a1ce3d50fdbdc77 100644
--- a/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryPortTypeGeneration.java
+++ b/org.fortiss.af3.platform.raspberry/trunk/src/org/fortiss/af3/platform/raspberry/generated/files/RaspberryPortTypeGeneration.java
@@ -26,24 +26,25 @@ package org.fortiss.af3.platform.raspberry.generated.files;
  */
 public class RaspberryPortTypeGeneration {
 
-	private String status;
+	/** Information relevant to the ports. */
+	private String portInfo;
 
 	/** Contents of the PortsInfo. */
 	private String content;
 
 	/** Constructor. */
-	public RaspberryPortTypeGeneration(String info) {
-		this.status = info;
+	public RaspberryPortTypeGeneration(String portSpecs) {
+		this.portInfo = portSpecs;
 		this.content = "";
 	}
 
 	/** Calls the methods that create the Infofile. */
 
 	public void createInfofile() {
-		content += status;
+		content += portInfo;
 	}
 
-	/** Return the current content of the Infofile. */
+	/** Return the current content of the portSpecs. */
 	public String getContent() {
 		return this.content;
 	}
@@ -26,24 +26,25 @@ package org.fortiss.af3.platform.raspberry.generated.files;
 	}
 
-	/** Calls the methods that create the Infofile. */
+	/** Calls the methods that create the portSpecs. */
 
 	public void createInfofile() {